@@ -7,12 +7,12 @@
 //! seconds since the beginning of the week. In GPS time the week begins at
 //! midnight on Sunday.
 //!
-//! [`GpsTime`] is the primary representation used in swiftnav-rs. Other time bases
+//! [`GpsTime`] is the primary representation used in swiftnav. Other time bases
 //! are available, such as [`UtcTime`], [`GalTime`], [`BdsTime`], and [`GloTime`]
 //! along with conversions for all of these to and from [`GpsTime`].
 //! Not all functionality is available in these other representations, so it's
 //! intended that all times are to converted to [`GpsTime`] before use with
-//! swiftnav-rs.
+//! swiftnav.
 //!
 //! # ⚠️  🦘  ⏱  ⚠️  - Leap Seconds
 //! UTC time occasinally adds additional seconds to keep it synchronized with the
@@ -20,11 +20,11 @@
 //! GNSS time bases ignore leap seconds and thus slowly grow out of sync with UTC.
 //! This is fine when dealing with GNSS data, but it's common that people want time
 //! to be represented as a UTC time since that's what people are more familiar with.
-//! swiftnav-rs provides ways to convert to and from UTC synchronized time bases
+//! swiftnav provides ways to convert to and from UTC synchronized time bases
 //! and is able to correctly compensate for leap seconds in two ways.
 //!
 //! The first is by using the UTC conversion parameters broadcast by GNSS systems
-//! that receivers can decode. [`UtcParams`] is how swiftnav-rs represents this
+//! that receivers can decode. [`UtcParams`] is how swiftnav represents this
 //! information, and [`UtcParams::decode()`] is provided for decoding the raw GPS
 //! navigation subframe with this information. This is the prefered method since it
 //! is usually available when processing raw GNSS data and ensures that the right
@@ -85,7 +85,7 @@ impl fmt::Display for InvalidGpsTime {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         match self {
             InvalidGpsTime::InvalidWN(wn) => write!(f, "Invalid Week Number: {}", wn),
-            InvalidGpsTime::InvalidTOW(tow) => write!(f, "Invalid Time of Wee: {}", tow),
+            InvalidGpsTime::InvalidTOW(tow) => write!(f, "Invalid Time of Week: {}", tow),
         }
     }
 }
@@ -123,6 +123,10 @@ impl GpsTime {
         &self.0
     }
 
+    pub(crate) fn mut_c_ptr(&mut self) -> *mut swiftnav_sys::gps_time_t {
+        &mut self.0
+    }
+
     pub(crate) fn unknown() -> swiftnav_sys::gps_time_t {
         swiftnav_sys::gps_time_t { tow: -1.0, wn: -1 }
     }
@@ -728,6 +732,29 @@ impl UtcTime {
             self.seconds()
         )
     }
+
+    /// Converts the UTC time into GPS time
+    pub fn to_gps(&self, utc_params: &UtcParams) -> GpsTime {
+        let mut gps = GpsTime::new_unchecked(0, 0.0);
+        unsafe {
+            swiftnav_sys::utc2gps(self.c_ptr(), gps.mut_c_ptr(), utc_params.c_ptr());
+        }
+        gps
+    }
+
+    /// Converts the UTC time into GPS time using the hardcoded list of leap
+    /// seconds.
+    ///
+    /// # ⚠️  🦘  ⏱  ⚠️  - Leap Seconds
+    /// The hard coded list of leap seconds will get out of date, it is
+    /// preferable to use [`UtcTime::to_gps()`] with the newest set of UTC parameters
+    pub fn to_gps_hardcoded(&self) -> GpsTime {
+        let mut gps = GpsTime::new_unchecked(0, 0.0);
+        unsafe {
+            swiftnav_sys::utc2gps(self.c_ptr(), gps.mut_c_ptr(), std::ptr::null());
+        }
+        gps
+    }
 }
 
 impl Default for UtcTime {
